@@ -4,7 +4,7 @@ context("Add daily volume")
 
 test_that("dataframe can be provided and using different column names",{
   skip_on_cran()
-  skip_on_travis()
+  skip_on_ci()
   flowdata <- tidyhydat::hy_daily_flows("08NM116") %>% 
     dplyr::rename(Flows = Value)
   flowdata <- add_daily_volume(flowdata, values = Flows)
@@ -14,7 +14,7 @@ test_that("dataframe can be provided and using different column names",{
 
 test_that("station_number can be provided",{
   skip_on_cran()
-  skip_on_travis()
+  skip_on_ci()
   stns <- "08NM003"
   stations_data <- add_daily_volume(station_number = stns)
   expect_true(stns %in% unique(stations_data$STATION_NUMBER) &
@@ -23,7 +23,7 @@ test_that("station_number can be provided",{
 
 test_that("multiple station_numbers can be provided",{
   skip_on_cran()
-  skip_on_travis()
+  skip_on_ci()
   stns <- c("08NM003","08NM116")
   stations_data <- add_daily_volume(station_number = stns)
   expect_true(all(unique(stations_data$STATION_NUMBER) %in% stns) &
@@ -34,7 +34,7 @@ test_that("multiple station_numbers can be provided",{
 
 test_that("add_daily_volume actually adds a column called Volume_m3",{
   skip_on_cran()
-  skip_on_travis()
+  skip_on_ci()
   stns <- "08NM003"
   data_col <- add_daily_volume(station_number = stns)
   expect_true("Volume_m3" %in% names(data_col))
