@@ -2,7 +2,7 @@ context("Plot annual stats")
 
 test_that("a list of plots is created", {
   skip_on_cran()
-  skip_on_travis()
+  skip_on_ci()
   plots <- plot_annual_stats(station_number = "08NM116",
                              start_year = 1981,
                              end_year = 2010,
@@ -12,7 +12,7 @@ test_that("a list of plots is created", {
 
 test_that("multiple plots are created with multiple groups", {
   skip_on_cran()
-  skip_on_travis()
+  skip_on_ci()
   plots <- plot_annual_stats(station_number = c("08NM116","08NM242"),
                              ignore_missing = TRUE)
   expect_true(length(plots) == 2)
